package
module
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Nov 12, 2024
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Notify
Golang 推送通知 SDK (钉钉群机器人、飞书群机器人、企业微信群机器人、邮件)。
支持的平台
安装
环境要求
引入本包
go get -u github.com/sunmking/notify
使用
钉钉机器人
前置准备
请先阅读一遍官方的文档 钉钉群机器人,熟悉里面的各种名词概念。
支持的消息类型
- text类型
- link类型
- markdown类型
- ActionCard类型
- FeedCard类型
调用
// Text Message
// Link Message
// Markdown Message
// Feed Card Message
// Single Action Card Message
// Btns Action Card Message
飞书群群机器人
前置准备
请先阅读一遍官方的文档 飞书群机器人配置说明,熟悉里面的各种名词概念。
支持的消息类型
- 文本 text
- 富文本 post
- 群名片 share_chat
- 图片 image
- 消息卡片 interactive
调用
企业微信群机器人
前置准备
请先阅读一遍官方的文档 企业微信群机器人配置说明,熟悉里面的各种名词概念。
支持的消息类型
- 文本 text
- markdown
- 图片 image
- 图文 news
- 模版卡片 template_card
调用
特别感谢
本项目借鉴了下面开源项目的思路,在此表示感谢,排名不分先后。
License
MIT
Documentation
¶
type IClient interface {
Send(msg any) error
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.